import request from '@/utils/request'

export function serviceCaseCover(query) {
  return request({
    url: '/cover',
    method: 'get',
    params: query
  })
}

export function addCaseCover(data) {
  return request({
    url: '/cover/add',
    method: 'post',
    data
  })
}

export function deleteServiceBatch(data) {
  return request({
    url: '/service/delete',
    method: 'delete',
    data
  })
}

export function getCaseListData(query) {
  return request({
    url: '/case/list',
    method: 'get',
    params: query
  })
}

export function getCaseTypeListData(query) {
  return request({
    url: '/caseTypes',
    method: 'get'
  })
}

export function addCase(data) {
  return request({
    url: '/case/add',
    method: 'post',
    data
  })
}

export function serviceCaseList(query) {
  return request({
    url: 'caseType/case/list',
    method: 'get',
    params: query
  })
}

export function serviceMovementList(query) {
  return request({
    url: 'caseType/movement/list',
    method: 'get',
    params: query
  })
}

export function addServiceCase(data) {
  return request({
    url: '/caseType/add',
    method: 'post',
    data
  })
}

export function deleteServiceCaseBatch(data) {
  return request({
    url: '/caseType/delete',
    method: 'delete',
    data
  })
}

export function deleteCaseBatch(data) {
  return request({
    url: '/case/delete',
    method: 'delete',
    data
  })
}

export function getCaseDetailById(id) {
  return request({
    url: '/case/' + id,
    method: 'get'
  })
}
